@@ -61,7 +61,7 @@ MMPC <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini
     if (is.null(hashObject) )  {
       stat_hash <- Rfast::Hash();
       pvalue_hash <- Rfast::Hash();
-    } else if ( identical( class(hashObject), "list" ) ) {
+    } else if ( is.list(hashObject) ) {
       stat_hash <- hashObject$stat_hash;
       pvalue_hash <- hashObject$pvalue_hash;
     } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
@@ -69,10 +69,10 @@ MMPC <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini
   ###################################
   # dataset checking and initialize #
   ###################################
-  if ( !is.null(dataset) ) {
-    if ( sum( class(target) == "matrix") == 1 )  {
-      if ( sum( class(target) == "Surv") == 1 )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');      
-    }   
+  #if ( !is.null(dataset) ) {
+  #  if ( is.matrix(target) )  {
+  #    if ( !is.Surv(target) )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');      
+  #  }   
     #check if dataset is an ExpressionSet object of Biobase package
     # if(class(dataset) == "ExpressionSet") {
       #get the elements (numeric matrix) of the current ExpressionSet object.
@@ -86,7 +86,7 @@ MMPC <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini
    # } else if((class(dataset) != "matrix") & (is.data.frame(dataset) == FALSE) ) {
    #   stop('Invalid dataset class. It must be either a matrix, a dataframe or an ExpressionSet');
    # }	
-  }
+  #}
   if( is.null(dataset) || is.null(target) ) {  #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
   } else  target <- target;
@@ -354,7 +354,7 @@ MMPC <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL, ini
   }
   runtime <- proc.time() - runtime
   
-  MMPCoutput <-new("MMPCoutput", selectedVars = results$selectedVars, selectedVarsOrder = results$selectedVarsOrder, 
+  MMPCoutput <- new("MMPCoutput", selectedVars = results$selectedVars, selectedVarsOrder = results$selectedVarsOrder, 
                    hashObject = results$hashObject, pvalues=results$pvalues, stats = results$stats, univ = results$univ, 
                    max_k = results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime = runtime, 
                    test = ci_test);
