@@ -11,7 +11,7 @@ perm.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     if (is.null(hashObject) )  {
       stat_hash <- Rfast::Hash();
       pvalue_hash <- Rfast::Hash();
-    } else if ( class(hashObject) == "list" ) {
+    } else if ( is.list( hashObject ) ) {
       stat_hash <- hashObject$stat_hash;
       pvalue_hash <- hashObject$pvalue_hash;
     } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
@@ -19,11 +19,11 @@ perm.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
   ###################################
   # dataset checking and initialize #
   ###################################
-  if ( !is.null(dataset) ) {
-    if ( sum( class(target) == "matrix") == 1 )  {
-      if ( sum( class(target) == "Surv") == 1 )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');      
-    }   
-  }
+  #if ( !is.null(dataset) ) {
+  #  if ( is.matrix(target) )  {
+  #    if ( !is.Surv(target) )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');      
+  #  }   
+  #}
   if( is.null(dataset) || is.null(target) ) {  #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
   } else  target <- target;
@@ -55,8 +55,8 @@ perm.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     target <- dataset[ , targetID];
   }
   
-  if ( sum( class(target) == "matrix") == 1 ) {
-    if (ncol(target) >= 2 & class(target) != "Surv") {
+  if ( is.matrix(target) ) {
+    if ( ncol(target) >= 2  &  !is.Surv( target ) ) {
       if ( (is.null(test) || test == "auto") & (is.null(user_test)) ) {
         test = "testIndMVreg"
       }
@@ -73,7 +73,7 @@ perm.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     if (is.null(test) || test == "auto") {
       
       if ( la == 2 )   target <- as.factor(target)
-      if ( sum( class(target) == "matrix") == 1 )  test = "testIndMVreg"
+      if ( is.matrix(target) )  test = "testIndMVreg"
       
       #if target is a factor then use the Logistic test
       if ( "factor" %in% class(target) )  {
@@ -88,7 +88,7 @@ perm.mmpc <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
         if ( sum( floor(target) - target ) == 0  &  la > 2 ) {
           test = "permPois";
         } else {
-          if(class(dataset) == "matrix") {
+          if( is.matrix(dataset) ) {
             test = "permFisher";
           } 
           else if ( is.data.frame(dataset) ) {
