@@ -11,7 +11,7 @@ wald.ses <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
     if (is.null(hashObject) )  {
       stat_hash <- Rfast::Hash();
       pvalue_hash <- Rfast::Hash();
-    } else if ( class(hashObject) == "list" ) {
+    } else if ( is.list( hashObject ) ) {
       stat_hash <- hashObject$stat_hash;
       pvalue_hash <- hashObject$pvalue_hash;
     } else   stop('hashObject must be a list of two hash objects (stat_hash, pvalue_hash)')
@@ -19,11 +19,11 @@ wald.ses <- function(target, dataset, max_k = 3, threshold = 0.05, test = NULL,
   ###################################
   # dataset checking and initialize #
   ###################################
-  if ( !is.null(dataset) ) {
-    if( sum( class(target) == "matrix") == 1 ) {
-      if( sum( class(target) == "Surv") == 1 )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');
-    }
-  }
+  #if ( !is.null(dataset) ) {
+  #  if( is.matrix(target) ) {
+  #    if( !is.Surv(target) )  stop('Invalid dataset class. For survival analysis provide a dataframe-class dataset');
+  #  }
+  #}
   if( is.null(dataset) || is.null(target) ) {    #|| (dim(as.matrix(target))[2] != 1 & class(target) != "Surv" ))
     stop('invalid dataset or target (class feature) arguments.');
   } else  target <- target;
